@@ -587,6 +587,14 @@ ews_folder_get_message_sync (CamelFolder *folder,
 	return message;
 }
 
+static CamelMimeMessage *
+ews_folder_get_message_cached (CamelFolder *folder,
+			       const gchar *message_uid,
+			       GCancellable *cancellable)
+{
+	return camel_ews_folder_get_message_from_cache ((CamelEwsFolder *) folder, message_uid, cancellable, NULL);
+}
+
 static GPtrArray *
 ews_folder_search_by_expression (CamelFolder *folder,
                                  const gchar *expression,
@@ -1314,7 +1322,7 @@ sync_created_items (CamelEwsFolder *ews_folder,
 		goto exit;
 	}
 
-	camel_ews_utils_sync_created_items (ews_folder, cnc, items);
+	camel_ews_utils_sync_created_items (ews_folder, cnc, items, cancellable);
 	items = NULL;
 
 	if (post_item_ids)
@@ -1330,7 +1338,7 @@ sync_created_items (CamelEwsFolder *ews_folder,
 		goto exit;
 	}
 
-	camel_ews_utils_sync_created_items (ews_folder, cnc, items);
+	camel_ews_utils_sync_created_items (ews_folder, cnc, items, cancellable);
 	items = NULL;
 
 	if (generic_item_ids)
@@ -1340,7 +1348,7 @@ sync_created_items (CamelEwsFolder *ews_folder,
 			FALSE, NULL, &items, NULL, NULL,
 			cancellable, &local_error);
 
-	camel_ews_utils_sync_created_items (ews_folder, cnc, items);
+	camel_ews_utils_sync_created_items (ews_folder, cnc, items, cancellable);
 
 	if (local_error) {
 		camel_ews_store_maybe_disconnect (ews_store, local_error);
@@ -1796,7 +1804,7 @@ ews_folder_constructed (GObject *object)
 	settings = camel_service_ref_settings (service);
 
 	network_settings = CAMEL_NETWORK_SETTINGS (settings);
-	host = camel_network_settings_dup_host (network_settings);
+	host = camel_ews_utils_get_host_name (settings);
 	user = camel_network_settings_dup_user (network_settings);
 
 	g_object_unref (settings);
@@ -1824,6 +1832,7 @@ camel_ews_folder_class_init (CamelEwsFolderClass *class)
 
 	folder_class = CAMEL_FOLDER_CLASS (class);
 	folder_class->get_message_sync = ews_folder_get_message_sync;
+	folder_class->get_message_cached = ews_folder_get_message_cached;
 	folder_class->search_by_expression = ews_folder_search_by_expression;
 	folder_class->count_by_expression = ews_folder_count_by_expression;
 	folder_class->cmp_uids = ews_cmp_uids;
