@@ -1263,7 +1263,6 @@ gchar *
 ews_get_name (CamelService *service,
               gboolean brief)
 {
-	CamelNetworkSettings *network_settings;
 	CamelSettings *settings;
 	gchar *name;
 	gchar *host;
@@ -1271,9 +1270,8 @@ ews_get_name (CamelService *service,
 
 	settings = camel_service_ref_settings (service);
 
-	network_settings = CAMEL_NETWORK_SETTINGS (settings);
-	host = camel_network_settings_dup_host (network_settings);
-	user = camel_network_settings_dup_user (network_settings);
+	user = camel_network_settings_dup_user (CAMEL_NETWORK_SETTINGS (settings));
+	host = camel_ews_utils_get_host_name (settings);
 
 	g_object_unref (settings);
 
