@@ -47,6 +47,7 @@
 
 #include "e-ews-config-utils.h"
 #include "e-ews-search-user.h"
+#include "e-ews-subscribe-foreign-folder.h"
 
 struct RunWithFeedbackData
 {
@@ -107,8 +108,11 @@ run_with_feedback_idle (gpointer user_data)
 	}
 
 	if (!was_cancelled) {
-		if (rfd->error)
+		if (rfd->error) {
+			g_dbus_error_strip_remote_error (rfd->error);
+
 			e_notice (rfd->parent, GTK_MESSAGE_ERROR, "%s", rfd->error->message);
+		}
 	}
 
 	free_run_with_feedback_data (rfd);
@@ -458,7 +462,6 @@ get_ews_store_from_folder_tree (EShellView *shell_view,
 	return found;
 }
 
-#if 0
 static void
 action_subscribe_foreign_folder_cb (GtkAction *action,
                                     EShellView *shell_view)
@@ -479,9 +482,7 @@ action_subscribe_foreign_folder_cb (GtkAction *action,
 
 	g_object_unref (session);
 	g_object_unref (store);
-	g_free (profile);
 }
-#endif
 
 static void
 action_folder_permissions_mail_cb (GtkAction *action,
@@ -492,7 +493,6 @@ action_folder_permissions_mail_cb (GtkAction *action,
 	GtkWindow *parent;
 	CamelStore *store = NULL;
 	CamelEwsStore *ews_store;
-	CamelNetworkSettings *network_settings;
 	gchar *str_folder_id;
 
 	if (!get_ews_store_from_folder_tree (shell_view, &folder_path, &store))
@@ -502,9 +502,6 @@ action_folder_permissions_mail_cb (GtkAction *action,
 	g_return_if_fail (ews_store != NULL);
 	g_return_if_fail (folder_path != NULL);
 
-	network_settings = CAMEL_NETWORK_SETTINGS (camel_service_get_settings (CAMEL_SERVICE (store)));
-	g_return_if_fail (network_settings != NULL);
-
 	shell_window = e_shell_view_get_shell_window (shell_view);
 	parent = GTK_WINDOW (shell_window);
 
@@ -512,28 +509,43 @@ action_folder_permissions_mail_cb (GtkAction *action,
 	if (!str_folder_id) {
 		e_notice (parent, GTK_MESSAGE_ERROR, _("Cannot edit permissions of folder '%s', choose other folder."), folder_path);
 	} else {
-		ESourceRegistry *registry = e_shell_get_registry (e_shell_window_get_shell (shell_window));
+		EShell *shell;
 		ESource *source;
+		ESourceRegistry *registry;
+		CamelService *service;
+		CamelSettings *settings;
 		EwsFolderId *folder_id;
 		gchar *str_change_key;
+		const gchar *uid;
 
-		source = e_source_registry_ref_source (registry, camel_service_get_uid (CAMEL_SERVICE (store)));
+		shell = e_shell_window_get_shell (shell_window);
+		registry = e_shell_get_registry (shell);
+
+		service = CAMEL_SERVICE (store);
+		uid = camel_service_get_uid (service);
+		source = e_source_registry_ref_source (registry, uid);
 		g_return_if_fail (source != NULL);
 
-		str_change_key = camel_ews_store_summary_get_change_key (ews_store->summary, str_folder_id, NULL);
+		str_change_key = camel_ews_store_summary_get_change_key (
+			ews_store->summary, str_folder_id, NULL);
 
-		folder_id = e_ews_folder_id_new (str_folder_id, str_change_key, FALSE);
+		folder_id = e_ews_folder_id_new (
+			str_folder_id, str_change_key, FALSE);
+
+		settings = camel_service_ref_settings (service);
 
 		e_ews_edit_folder_permissions (
 			parent,
 			registry,
 			source,
-			CAMEL_EWS_SETTINGS (network_settings),
-			camel_service_get_display_name (CAMEL_SERVICE (store)),
+			CAMEL_EWS_SETTINGS (settings),
+			camel_service_get_display_name (service),
 			folder_path,
 			folder_id,
 			E_EWS_FOLDER_TYPE_MAILBOX);
 
+		g_object_unref (settings);
+
 		g_object_unref (source);
 		g_free (str_folder_id);
 		g_free (str_change_key);
@@ -569,17 +581,15 @@ ews_ui_enable_actions (GtkActionGroup *action_group,
 	}
 }
 
-#if 0
 static GtkActionEntry mail_account_context_entries[] = {
 
 	{ "mail-ews-subscribe-foreign-folder",
 	  NULL,
 	  N_("Subscribe to folder of other user..."),
 	  NULL,
-	  NULL,  / * XXX Add a tooltip! * /
+	  NULL,  /* XXX Add a tooltip! */
 	  G_CALLBACK (action_subscribe_foreign_folder_cb) }
 };
-#endif
 
 static GtkActionEntry mail_folder_context_entries[] = {
 	{ "mail-ews-folder-permissions",
@@ -593,7 +603,7 @@ static GtkActionEntry mail_folder_context_entries[] = {
 static const gchar *ews_ui_mail_def =
 	"<popup name=\"mail-folder-popup\">\n"
 	"  <placeholder name=\"mail-folder-popup-actions\">\n"
-	/*"    <menuitem action=\"mail-ews-subscribe-foreign-folder\"/>\n"*/
+	"    <menuitem action=\"mail-ews-subscribe-foreign-folder\"/>\n"
 	"    <menuitem action=\"mail-ews-folder-permissions\"/>\n"
 	"  </placeholder>\n"
 	"</popup>\n";
@@ -648,7 +658,7 @@ ews_ui_update_actions_mail_cb (EShellView *shell_view,
 			g_object_unref (session);
 	}
 
-	/* ews_ui_enable_actions (action_group, mail_account_context_entries, G_N_ELEMENTS (mail_account_context_entries), account_node, online); */
+	ews_ui_enable_actions (action_group, mail_account_context_entries, G_N_ELEMENTS (mail_account_context_entries), account_node, online);
 	ews_ui_enable_actions (action_group, mail_folder_context_entries, G_N_ELEMENTS (mail_folder_context_entries), folder_node, online);
 }
 
@@ -668,8 +678,9 @@ ews_ui_init_mail (GtkUIManager *ui_manager,
 	action_group = e_shell_window_get_action_group (shell_window, "mail");
 
 	/* Add actions to the "mail" action group. */
-	/*e_action_group_add_actions_localized (action_group, GETTEXT_PACKAGE,
-		mail_account_context_entries, G_N_ELEMENTS (mail_account_context_entries), shell_view);*/
+	e_action_group_add_actions_localized (
+		action_group, GETTEXT_PACKAGE,
+		mail_account_context_entries, G_N_ELEMENTS (mail_account_context_entries), shell_view);
 	e_action_group_add_actions_localized (
 		action_group, GETTEXT_PACKAGE,
 		mail_folder_context_entries, G_N_ELEMENTS (mail_folder_context_entries), shell_view);
