@@ -33,16 +33,29 @@
 #include "e-ews-item.h"
 #include "camel-ews-settings.h"
 
+/* Standard GObject macros */
+#define E_TYPE_EWS_CONNECTION \
+	(e_ews_connection_get_type ())
+#define E_EWS_CONNECTION(obj) \
+	(G_TYPE_CHECK_INSTANCE_CAST \
+	((obj), E_TYPE_EWS_CONNECTION, EEwsConnection))
+#define E_EWS_CONNECTION_CLASS(cls) \
+	(G_TYPE_CHECK_CLASS_CAST \
+	((cls), E_TYPE_EWS_CONNECTION, EEwsConnectionClass))
+#define E_IS_EWS_CONNECTION(obj) \
+	(G_TYPE_CHECK_INSTANCE_TYPE \
+	((obj), E_TYPE_EWS_CONNECTION))
+#define E_IS_EWS_CONNECTION_CLASS(cls) \
+	(G_TYPE_CHECK_CLASS_TYPE \
+	((cls), E_TYPE_EWS_CONNECTION))
+#define E_EWS_CONNECTION_GET_CLASS(obj) \
+	(G_TYPE_INSTANCE_GET_CLASS \
+	((obj), E_TYPE_EWS_CONNECTION, EEwsConnectionClass))
+
 G_BEGIN_DECLS
 
-#define E_TYPE_EWS_CONNECTION            (e_ews_connection_get_type ())
-#define E_EWS_CONNECTION(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), E_TYPE_EWS_CONNECTION, EEwsConnection))
-#define E_EWS_CONNECTION_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), E_TYPE_EWS_CONNECTION, EEwsConnectionClass))
-#define E_IS_EWS_CONNECTION(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), E_TYPE_EWS_CONNECTION))
-#define E_IS_EWS_CONNECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), E_TYPE_EWS_CONNECTION))
-
-typedef struct _EEwsConnection        EEwsConnection;
-typedef struct _EEwsConnectionClass   EEwsConnectionClass;
+typedef struct _EEwsConnection EEwsConnection;
+typedef struct _EEwsConnectionClass EEwsConnectionClass;
 typedef struct _EEwsConnectionPrivate EEwsConnectionPrivate;
 
 struct _EEwsConnection {
@@ -52,8 +65,6 @@ struct _EEwsConnection {
 
 struct _EEwsConnectionClass {
 	GObjectClass parent_class;
-
-	void (*authenticate) (EEwsConnection *cnc);
 };
 
 enum {
@@ -909,6 +920,50 @@ gboolean	e_ews_connection_set_folder_permissions_sync
 						 GCancellable *cancellable,
 						 GError **error);
 
+void		e_ews_connection_get_password_expiration
+						(EEwsConnection *cnc,
+						 gint pri,
+						 const gchar *mail_id,
+						 GCancellable *cancellable,
+						 GAsyncReadyCallback callback,
+						 gpointer user_data);
+
+gboolean	e_ews_connection_get_password_expiration_finish
+						(EEwsConnection *cnc,
+						 GAsyncResult *result,
+						 gchar **exp_date,
+						 GError **error);
+
+gboolean	e_ews_connection_get_password_expiration_sync
+						(EEwsConnection *cnc,
+						 gint pri,
+						 const gchar *mail_id,
+						 gchar **exp_date,
+						 GCancellable *cancellable,
+						 GError **error);
+
+void		e_ews_connection_get_folder_info
+						(EEwsConnection *cnc,
+						 gint pri,
+						 const gchar *mail_id,
+						 const EwsFolderId *folder_id,
+						 GCancellable *cancellable,
+						 GAsyncReadyCallback callback,
+						 gpointer user_data);
+gboolean	e_ews_connection_get_folder_info_finish
+						(EEwsConnection *cnc,
+						 GAsyncResult *result,
+						 EEwsFolder **folder,
+						 GError **error);
+gboolean	e_ews_connection_get_folder_info_sync
+						(EEwsConnection *cnc,
+						 gint pri,
+						 const gchar *mail_id,
+						 const EwsFolderId *folder_id,
+						 EEwsFolder **folder,
+						 GCancellable *cancellable,
+						 GError **error);
+
 G_END_DECLS
 
 #endif
